@@ -42,7 +42,7 @@ use version 0.77;
 
 # PODNAME: Dist::Zilla::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = 'v0.8.7'; # VERSION
+our $VERSION = 'v0.9.0'; # VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -231,7 +231,7 @@ has unwanted_modules => (
 #pod stdout misspelled words. If empty, spellchecking will be skipped. This involve C<Test::PodSpelling>
 #pod plugin and internally implemented checking the F<Changes> file.
 #pod
-#pod Optional, default value C<aspell list -l en -p ./xt/aspell.en.pws>.
+#pod Optional, default value C<aspell list -l en -p ./xt/aspell-en.pws>.
 #pod
 #pod =cut
 
@@ -241,7 +241,7 @@ has spellchecker => (
     lazy        => 1,
     default     => sub {
         my ( $self ) = @_;
-        return $self->payload->{ spellchecker } // 'aspell list -l en -p ./xt/aspell.en.pws';
+        return $self->payload->{ spellchecker } // 'aspell list -l en -p ./xt/aspell-en.pws';
             #   Leading dot (in `./xt/aspell.en.pws`) is important! Whitout the dot `aspell`
             #   fails to find the dictionary.
     },
@@ -379,6 +379,16 @@ sub configure {
             ] ],
         } ],
 
+        #   I would like to set `is_strict` option to `1`, but it will fail for trial releases.
+        #   To avoid that let's do a trick: set `is_strict` to `1` only in case of non-trial
+        #   release.
+        [ 'Hook::BeforeBuild' => 'hack Test::Version' => {
+            'hook' => [ q[
+                my $tv = $zilla->plugin_named( '@Author::VDB/Test::Version' );
+                $tv->{ is_strict } = $dist->is_trial ? '0' : '1';
+            ] ],
+        } ],
+
         #
         #   Files to include
         #
@@ -511,6 +521,8 @@ sub configure {
 
         # Files
 
+        [ 'Test::Portability' ],        # Checks filenames.
+
         [ 'Test::EOL' => {
             'finder' => '@Author::VDB/Manifest::Read',
         } ],
@@ -528,7 +540,7 @@ sub configure {
         } ],
 
         [ 'Test::Version' => {          # All modules have version.
-            #~ 'is_strict' => 1,        # Does not work for trial releases.
+            'is_strict' => 0,           # Strict version test fails in trial releases.
         } ],
 
         [ 'Test::NewVersion' ],         # This is not a version already uploaded to CPAN.
@@ -557,8 +569,12 @@ sub configure {
         ) : (
         ),
 
+        [ 'Test::Pod::LinkCheck' ],
+
         [ 'Test::Pod::No404s' ],    # No dead URLs.
 
+        [ 'Test::Synopsis' ],
+
         # Metadata
 
         [ 'MetaTests' ],    # `Dist-Zilla`-bundled test, uses `Test::CPAN::Meta`, checks `META.yml`.
@@ -773,6 +789,9 @@ sub configure {
         ),
 
         #   Make sure there is no such tag yet, neither global nor local.
+        #   Is seems direct scanning `.hgtags` and hg/localtags` does not always work in case of
+        #   branches. Parsing `hg tag` may be more correct.
+        #   TODO: Check it.
         [ 'Hook::BeforeRelease' => 'hg check tag' => {
             'hook' => [ q{
                 use Path::Tiny;
@@ -958,7 +977,7 @@ Dist::Zilla::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version v0.8.7, released on 2015-10-03 13:38 UTC.
+Version v0.9.0, released on 2015-10-11 20:32 UTC.
 
 =head1 WHAT?
 
@@ -1033,7 +1052,7 @@ Command to run spellchecker. Spellchecker command is expected to read text from
 stdout misspelled words. If empty, spellchecking will be skipped. This involve C<Test::PodSpelling>
 plugin and internally implemented checking the F<Changes> file.
 
-Optional, default value C<aspell list -l en -p ./xt/aspell.en.pws>.
+Optional, default value C<aspell list -l en -p ./xt/aspell-en.pws>.
 
 =head1 WHY?
 
@@ -1204,7 +1223,7 @@ distribution should not.
 
 \=item *
 
-Source should contain files F<dist.ini>, F<weaver.ini>, while distribution may not.
+Source should contain F<dist.ini> file, while distribution may not.
 
 \=item *
 
@@ -1213,7 +1232,7 @@ Source should I<not> contain F<xt/> directory, while distribution should.
 \=item *
 
 Name of source directory does I<not> include version (e. g. C<{{$MY::name}}>), while name of
-distribution does (e. g. C<{{$MY::name}}-0.007>).
+distribution does (e. g. C<{{$MY::name}}-v0.7.1>).
 
 \=back
 
@@ -1320,14 +1339,14 @@ To install the latest version from CPAN:
 
     $ cpanm {{$MY::package}}
 
-To install a specific version (e. g. I<0.007>) from CPAN:
+To install a specific version (e. g. I<v0.7.1>) from CPAN:
 
-    $ cpanm {{$MY::package}}@0.007
+    $ cpanm {{$MY::package}}@v0.7.1
 
 To install locally available distribution (e. g. previously downloaded from CPAN or built from
 sources):
 
-    $ cpanm ./{{$MY::name}}-0.007.tar.gz
+    $ cpanm ./{{$MY::name}}-v0.7.1.tar.gz
 
 To uninstall the distribution:
 
@@ -1335,11 +1354,11 @@ To uninstall the distribution:
 
 \=head2 Manually
 
-To install distribution tarball manually (let us assume you have version I<0.007> of the
+To install distribution tarball manually (let us assume you have version I<v0.7.1> of the
 distribution):
 
-    $ tar xaf {{$MY::name}}-0.007.tar.gz
-    $ cd {{$MY::name}}-0.007
+    $ tar xaf {{$MY::name}}-v0.7.1.tar.gz
+    $ cd {{$MY::name}}-v0.7.1
     $ perl Build.PL
     $ ./Build build
     $ ./Build test
